==> xfig.3.1.4.tar.gz: xfig.3.1.4/d_picobj.c <==
/*
 * FIG : Facility for Interactive Generation of figures
 * Copyright (c) 1992 Brian Boyter
 * Parts Copyright (c) 1994 by Brian V. Smith
 * Parts Copyright (c) 1991 by Paul King
 *
 * The X Consortium, and any party obtaining a copy of these files from
 * the X Consortium, directly or indirectly, is granted, free of charge, a
 * full and unrestricted irrevocable, world-wide, paid up, royalty-free,
 * nonexclusive right and license to deal in this software and
 * documentation files (the "Software"), including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons who receive
 * copies from any such party to do so, with the only requirement being
 * that this copyright notice remain intact.  This license includes without
 * limitation a license to do the foregoing actions under any patents of
 * the party supplying this software to the X Consortium.
 */

#include "fig.h"
#include "resources.h"
#include "mode.h"
#include "object.h"
#include "paintop.h"
#include "u_create.h"
#include "u_elastic.h"
#include "u_list.h"
#include "w_canvas.h"
#include "w_mousefun.h"

/*************************** local declarations *********************/

static
		init_picobj_drawing(), create_picobj(),
		cancel_picobj();

picobj_drawing_selected()
{
    set_mousefun("corner point", "", "", "", "", "");
    canvas_kbd_proc = null_proc;
    canvas_locmove_proc = null_proc;
    canvas_leftbut_proc = init_picobj_drawing;
    canvas_middlebut_proc = null_proc;
    canvas_rightbut_proc = null_proc;
    set_cursor(arrow_cursor);
    reset_action_on();
}

static
init_picobj_drawing(x, y)
    int		    x, y;
{
    init_box_drawing(x, y);
    canvas_leftbut_proc = create_picobj;
    canvas_rightbut_proc = cancel_picobj;
}

static
cancel_picobj()
{
    elastic_box(fix_x, fix_y, cur_x, cur_y);
    picobj_drawing_selected();
    draw_mousefun_canvas();
}

static
create_picobj(x, y)
    int		    x, y;
{
    F_line	   *box;
    F_point	   *point;

    elastic_box(fix_x, fix_y, cur_x, cur_y);
    canvas_locmove_proc = null_proc;

    if ((point = create_point()) == NULL)
	return;

    point->x = fix_x;
    point->y = fix_y;
    point->next = NULL;

    if ((box = create_line()) == NULL) {
	free((char *) point);
	return;
    }
    box->type = T_PIC_BOX;
    box->style = SOLID_LINE;
    box->thickness = 1;
    box->pen_color = cur_pencolor;
    box->fill_color = DEFAULT;
    box->depth = cur_depth;
    box->pen_style = 0;
    box->join_style = 0;	/* not used */
    box->cap_style = 0;		/* not used */
    box->fill_style = UNFILLED;
    box->style_val = 0;

    if ((box->pic = create_pic()) == NULL) {
	free((char *) point);
	free((char *) box);
	return;
    }
    box->pic->file[0] = '\0';
    box->pic->bitmap = NULL;
    box->pic->numcols = 0;
    box->pic->subtype = 0;
    box->pic->bit_size.x = 0;
    box->pic->bit_size.y = 0;
    box->pic->flipped = 0;
    box->pic->hw_ratio = 0.0;
    box->pic->pixmap = 0;
    box->pic->pix_width = 0;
    box->pic->pix_height = 0;
    box->pic->pix_rotation = 0;
    box->pic->pix_flipped = 0;

    box->points = point;
    append_point(fix_x, y, &point);
    append_point(x, y, &point);
    append_point(x, fix_y, &point);
    append_point(fix_x, fix_y, &point);
    add_line(box);
    /* draw it and anything on top of it */
    redisplay_line(box);
    put_msg("Please enter name of Picture Object file in EDIT window");
    edit_item((char *) box, O_POLYLINE, 0, 0);
    picobj_drawing_selected();
    draw_mousefun_canvas();
}

==> xfig_3.2.0.orig.tar.gz: xfig.3.2/d_picobj.c <==
/*
 * FIG : Facility for Interactive Generation of figures
 * Copyright (c) 1992 Brian Boyter
 * Parts Copyright (c) 1994 by Brian V. Smith
 * Parts Copyright (c) 1991 by Paul King
 *
 * The X Consortium, and any party obtaining a copy of these files from
 * the X Consortium, directly or indirectly, is granted, free of charge, a
 * full and unrestricted irrevocable, world-wide, paid up, royalty-free,
 * nonexclusive right and license to deal in this software and
 * documentation files (the "Software"), including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software subject to the restriction stated
 * below, and to permit persons who receive copies from any such party to
 * do so, with the only requirement being that this copyright notice remain
 * intact.
 * This license includes without limitation a license to do the foregoing
 * actions under any patents of the party supplying this software to the 
 * X Consortium.
 *
 */

#include "fig.h"
#include "resources.h"
#include "mode.h"
#include "object.h"
#include "paintop.h"
#include "u_create.h"
#include "u_elastic.h"
#include "u_list.h"
#include "w_canvas.h"
#include "w_mousefun.h"

/*************************** local declarations *********************/

static
		init_picobj_drawing(), create_picobj(),
		cancel_picobj();

picobj_drawing_selected()
{
    set_mousefun("corner point", "", "", "", "", "");
    canvas_kbd_proc = null_proc;
    canvas_locmove_proc = null_proc;
    canvas_leftbut_proc = init_picobj_drawing;
    canvas_middlebut_proc = null_proc;
    canvas_rightbut_proc = null_proc;
    set_cursor(arrow_cursor);
    reset_action_on();
}

static
init_picobj_drawing(x, y)
    int		    x, y;
{
    init_box_drawing(x, y);
    canvas_leftbut_proc = create_picobj;
    canvas_rightbut_proc = cancel_picobj;
}

static
cancel_picobj()
{
    elastic_box(fix_x, fix_y, cur_x, cur_y);
    picobj_drawing_selected();
    draw_mousefun_canvas();
}

static
create_picobj(x, y)
    int		    x, y;
{
    F_line	   *box;
    F_point	   *point;

    elastic_box(fix_x, fix_y, cur_x, cur_y);
    canvas_locmove_proc = null_proc;

    if ((point = create_point()) == NULL)
	return;

    point->x = fix_x;
    point->y = fix_y;
    point->next = NULL;

    if ((box = create_line()) == NULL) {
	free((char *) point);
	return;
    }
    box->type = T_PICTURE;
    box->style = SOLID_LINE;
    box->thickness = 1;
    box->pen_color = cur_pencolor;
    box->fill_color = DEFAULT;
    box->depth = cur_depth;
    box->pen_style = 0;
    box->join_style = 0;	/* not used */
    box->cap_style = 0;		/* not used */
    box->fill_style = UNFILLED;
    box->style_val = 0;

    if ((box->pic = create_pic()) == NULL) {
	free((char *) point);
	free((char *) box);
	return;
    }
    box->pic->file[0] = '\0';
    box->pic->bitmap = NULL;
    box->pic->numcols = 0;
    box->pic->subtype = 0;
    box->pic->bit_size.x = 0;
    box->pic->bit_size.y = 0;
    box->pic->flipped = 0;
    box->pic->hw_ratio = 0.0;
    box->pic->pixmap = 0;
    box->pic->pix_width = 0;
    box->pic->pix_height = 0;
    box->pic->pix_rotation = 0;
    box->pic->pix_flipped = 0;

    box->points = point;
    append_point(fix_x, y, &point);
    append_point(x, y, &point);
    append_point(x, fix_y, &point);
    append_point(fix_x, fix_y, &point);
    add_line(box);
    /* draw it and anything on top of it */
    redisplay_line(box);
    put_msg("Please enter name of Picture Object file in EDIT window");
    edit_item((char *) box, O_POLYLINE, 0, 0);
    picobj_drawing_selected();
    draw_mousefun_canvas();
}
